==> durt-0.1.2.tar.gz: lib/src/gva/queries.dart <==
const String getHistory = r'''
  query ($pubkey: String!, $number: Int!, $cursor: String) {
        txsHistoryBc(
            script: $pubkey
            pagination: { pageSize: $number, ord: DESC, cursor: $cursor }
        ) {
            both {
                pageInfo {
                    hasPreviousPage
                    hasNextPage
                    startCursor
                    endCursor
                }
                edges {
                    direction
                    node {
                        currency
                        issuers
                        outputs
                        comment
                        writtenTime
                    }
                }
            }
        }
        txsHistoryMp(pubkey: $pubkey) {
            receiving {
                currency
                issuers
                comment
                outputs
            }
            sending {
                currency
                issuers
                comment
                outputs
            }
      }
      currentUd {
        amount
        base
      }
      balance(script: $pubkey) {
        amount
        base
    }
  }
  ''';

const String getBalance = r'''
  query ($pubkey: String!) {
      balance(script: $pubkey) {
        amount
        base
      }
      currentUd {
        amount
        base
      }
    }
  ''';

const String getWallets = r'''
query ($number: Int!, $cursor: String) {
  wallets(pagination: {ord: ASC, pageSize: $number, cursor: $cursor}) {
    pageInfo {
      hasNextPage
      endCursor
    }
    edges {
      node {
        script
        balance {
          amount
          base
        }
        idty {
          isMember
          username
        }
      }
    }
  }
}
''';

const String getId = r'''
query ($pubkey: PubKeyGva!) {
  idty(pubkey: $pubkey) {
    isMember
    username
  }
}
''';

const String genTransDocQuery = r'''
query ($recipient: PkOrScriptGva!, $issuer: PubKeyGva!, $amount: Int!, $comment: String!, $useMempool: Boolean!) {
  genTx(
    amount: $amount
    comment: $comment
    issuer: $issuer
    recipient: $recipient
    useMempoolSources: $useMempool
  )
}
''';

const String sendTransactionDocQuery = r'''
mutation ($signedDoc: String!){
  tx(
    rawTx: $signedDoc
    ) {
        version
        issuers
        outputs
    }
}
''';

==> durt-0.1.3.tar.gz: lib/src/gva/queries.dart <==
const String getHistory = r'''
  query ($pubkey: String!, $number: Int!, $cursor: String) {
        txsHistoryBc(
            script: $pubkey
            pagination: { pageSize: $number, ord: DESC, cursor: $cursor }
        ) {
            both {
                pageInfo {
                    hasPreviousPage
                    hasNextPage
                    startCursor
                    endCursor
                }
                edges {
                    direction
                    node {
                        currency
                        issuers
                        outputs
                        comment
                        writtenTime
                    }
                }
            }
        }
        txsHistoryMp(pubkey: $pubkey) {
            receiving {
                currency
                issuers
                comment
                outputs
            }
            sending {
                currency
                issuers
                comment
                outputs
            }
      }
      currentUd {
        amount
        base
      }
      balance(script: $pubkey) {
        amount
        base
    }
  }
  ''';

const String getBalance = r'''
  query ($pubkey: String!) {
      balance(script: $pubkey) {
        amount
        base
      }
      currentUd {
        amount
        base
      }
    }
  ''';

const String getWallets = r'''
query ($number: Int!, $cursor: String) {
  wallets(pagination: {ord: ASC, pageSize: $number, cursor: $cursor}) {
    pageInfo {
      hasNextPage
      endCursor
    }
    edges {
      node {
        script
        balance {
          amount
          base
        }
        idty {
          isMember
          username
        }
      }
    }
  }
}
''';

const String getId = r'''
query ($pubkey: PubKeyGva!) {
  idty(pubkey: $pubkey) {
    isMember
    username
  }
}
''';

const String genTransactionDocQuery = r'''
query ($recipient: PkOrScriptGva!, $issuer: PubKeyGva!, $amount: Int!, $comment: String!, $useMempool: Boolean!) {
  genTx(
    amount: $amount
    comment: $comment
    issuer: $issuer
    recipient: $recipient
    useMempoolSources: $useMempool
  )
}
''';

const String sendTransactionDocQuery = r'''
mutation ($signedDoc: String!){
  tx(
    rawTx: $signedDoc
    ) {
        version
        issuers
        outputs
    }
}
''';
